@@ -8,9 +8,10 @@
 import typing
 
 note = typing.Annotated
+Type = typing.TypeVar("Type", bound=type)
 
 
-def try_extract_type_notes(value: typing.Annotated | type) -> tuple[type, tuple]:
+def try_extract_type_notes(value: typing.Annotated | Type) -> tuple[Type, tuple]:
     if typing.get_origin(value) != typing.Annotated:
         return value, tuple()
     args = typing.get_args(value)
