@@ -122,7 +122,7 @@ def get_converter(type_: type | types.GenericAlias | types.UnionType) -> Callabl
 
             def converter(base_value: Any):
                 raw_values = json.loads(base_value) if isinstance(base_value, str) else base_value
-                if not isinstance(raw_values, (list, tuple)):
+                if not isinstance(raw_values, (list, tuple, set, frozenset)):
                     raise ValueError(f'Expected iterable, got {type(raw_values).__name__}: {raw_values}')
                 if not has_ellipsis and len(raw_values) != len(element_converters):
                     raise ValueError(f'Expected exactly {len(element_converters)} elements, got {len(raw_values)}')
@@ -133,7 +133,7 @@ def get_converter(type_: type | types.GenericAlias | types.UnionType) -> Callabl
 
             def converter(base_value: Any):
                 raw_values = json.loads(base_value) if isinstance(base_value, str) else base_value
-                if not isinstance(raw_values, (list, tuple)):
+                if not isinstance(raw_values, (list, tuple, set, frozenset)):
                     raise ValueError(f'Expected iterable, got {type(raw_values).__name__}: {raw_values}')
                 parsed_values = [element_converter(element) for element in raw_values]
                 result = container_type(parsed_values)
@@ -172,8 +172,12 @@ def convert_to_type(field_type: type[T], field_name: str, value: Any,
             # noinspection PyTypeChecker
             value = dict_to_dataclass(value, field_type)
         except FieldErrors as e:
-            for field, error in e.field_to_error.items():
-                write_to_dict_or_raise(field_name_to_error, key=f'{field_name}.{field}', exception=error)
+            if field_name_to_error is not None:
+                for field, error in e.field_to_error.items():
+                    write_to_dict_or_raise(field_name_to_error, key=f'{field_name}.{field}', exception=error)
+            else:
+                raise FieldErrors(
+                    {f'{field_name}.{field}': error for field, error in e.field_to_error.items()}) from None
     else:
         try:
             converter = get_converter(field_type)
